@@ -30,20 +30,20 @@ class VidPlot(object):
 
         return img
 
-    def add(self, fig, dpi=160):
-        self.writer.append_data(VidPlot.get_img_from_fig(fig, dpi))
 
-    def addP(self, fig, progress, dpi=160):
+    def add(self, fig, progress=None, dpi=160):
         self.writer.append_data(VidPlot.get_img_from_fig(fig, dpi))
-        print("Progress : {:.3f}%".format(progress * 100))
-        clear_output(wait=True)
+        if progress is not None:
+            print("Progress : {:.3f}%".format(progress * 100))
+            clear_output(wait=True)
 
-    def finnish(self, width=600):
+    def finish(self, width=600, show=False):
         self.writer.close()
         self.__done = True
-        return self.show(width)
+        if show:
+            return self.show(width)
 
-    def showVideo(name, width=600):
+    def plot(name, width=600):
         return Video(name, width=width, embed=True)
 
     def show(self, width=600):
